package com.ruoyi.frequency.workstype.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.controller.req.StorePageReq;
import com.ruoyi.controller.resp.StorePageResp;
import com.ruoyi.frequency.workstype.entity.WorksType;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 作品类型Mapper接口
 * 
 * @author zj
 * @date 2023-09-22
 */
public interface WorksTypeMapper  extends BaseMapper<WorksType>
{
    /**
     * 查询作品类型
     * 
     * @param id 作品类型主键
     * @return 作品类型
     */
    public WorksType selectWorksTypeById(Long id);

    /**
     * 查询作品类型列表
     * 
     * @param worksType 作品类型
     * @return 作品类型集合
     */
    public List<WorksType> selectWorksTypeList(WorksType worksType);

    /**
     * 新增作品类型
     * 
     * @param worksType 作品类型
     * @return 结果
     */
    public int insertWorksType(WorksType worksType);

    /**
     * 修改作品类型
     * 
     * @param worksType 作品类型
     * @return 结果
     */
    public int updateWorksType(WorksType worksType);

    /**
     * 删除作品类型
     * 
     * @param id 作品类型主键
     * @return 结果
     */
    public int deleteWorksTypeById(Long id);

    /**
     * 批量删除作品类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWorksTypeByIds(Long[] ids);

    Page<StorePageResp> storePage(@Param("page") Page<Object> objectPage, @Param("req")StorePageReq req, @Param("userVo") UserVo userVo);
}
